summaryrefslogtreecommitdiffstats
path: root/kommander/factory/domtool.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kommander/factory/domtool.cpp')
-rw-r--r--kommander/factory/domtool.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kommander/factory/domtool.cpp b/kommander/factory/domtool.cpp
index 0bd7088c..e532dc10 100644
--- a/kommander/factory/domtool.cpp
+++ b/kommander/factory/domtool.cpp
@@ -1,7 +1,7 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -328,7 +328,7 @@ static bool toBool( const TQString& s )
}
/*!
- Convert Qt 2.x format to Qt 3.0 format if necessary
+ Convert TQt 2.x format to TQt 3.0 format if necessary
*/
void DomTool::fixDocument( TQDomDocument& doc )
{
@@ -360,9 +360,9 @@ void DomTool::fixDocument( TQDomDocument& doc )
bool stdset = toBool( e.attribute( "stdset" ) );
if ( stdset || name == "toolTip" || name == "whatsThis" ||
name == "buddy" ||
- e.parentNode().toElement().tagName() == "item" ||
- e.parentNode().toElement().tagName() == "spacer" ||
- e.parentNode().toElement().tagName() == "column"
+ e.tqparentNode().toElement().tagName() == "item" ||
+ e.tqparentNode().toElement().tagName() == "spacer" ||
+ e.tqparentNode().toElement().tagName() == "column"
)
e.removeAttribute( "stdset" );
else
@@ -1,7 +1,7 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the